# Local Setup and Testing
Set up Python virtual environment

```bash
python -m venv local
source local/bin/activate
```

Install the project requirements
```bash
python -m pip install -r requirements.txt
```

Run the unit tests
```bash
cd tests
python -m unittest
```